/* This file is autogenerated by running:
 * scripts/keymap-render.py > src/libply-splash-graphics/ply-keymap-metadata.h
 */
typedef struct
{
        const char *name;
        int         offset;
        int         width;
        int         type;
} ply_keymap_metadata_t;

typedef enum
{
        PLY_LAYOUT_TERMINAL,
        PLY_LAYOUT_XKB,
} ply_layout_types_t;

static ply_keymap_metadata_t ply_keymap_metadata[] = {
        { "3l",                                        10,    47,  PLY_LAYOUT_TERMINAL },
        { "dvorak",                                    57,    113, PLY_LAYOUT_TERMINAL },
        { "adnw",                                      170,   94,  PLY_LAYOUT_TERMINAL },
        { "al",                                        264,   45,  PLY_LAYOUT_TERMINAL },
        { "amiga",                                     309,   103, PLY_LAYOUT_TERMINAL },
        { "apple",                                     412,   93,  PLY_LAYOUT_TERMINAL },
        { "applkey",                                   505,   126, PLY_LAYOUT_TERMINAL },
        { "ara",                                       631,   62,  PLY_LAYOUT_TERMINAL },
        { "at",                                        693,   46,  PLY_LAYOUT_TERMINAL },
        { "atari",                                     739,   81,  PLY_LAYOUT_TERMINAL },
        { "az",                                        820,   49,  PLY_LAYOUT_TERMINAL },
        { "azerty",                                    869,   105, PLY_LAYOUT_TERMINAL },
        { "ba",                                        974,   50,  PLY_LAYOUT_TERMINAL },
        { "backspace",                                 1024,  157, PLY_LAYOUT_TERMINAL },
        { "bashkir",                                   1181,  119, PLY_LAYOUT_TERMINAL },
        { "be",                                        1300,  50,  PLY_LAYOUT_TERMINAL },
        { "bg",                                        1350,  51,  PLY_LAYOUT_TERMINAL },
        { "bone",                                      1401,  84,  PLY_LAYOUT_TERMINAL },
        { "br",                                        1485,  48,  PLY_LAYOUT_TERMINAL },
        { "by",                                        1533,  51,  PLY_LAYOUT_TERMINAL },
        { "bywin",                                     1584,  98,  PLY_LAYOUT_TERMINAL },
        { "ca",                                        1682,  48,  PLY_LAYOUT_TERMINAL },
        { "carpalx",                                   1730,  118, PLY_LAYOUT_TERMINAL },
        { "cf",                                        1848,  46,  PLY_LAYOUT_TERMINAL },
        { "ch",                                        1894,  49,  PLY_LAYOUT_TERMINAL },
        { "cm",                                        1943,  59,  PLY_LAYOUT_TERMINAL },
        { "cn",                                        2002,  49,  PLY_LAYOUT_TERMINAL },
        { "croat",                                     2051,  89,  PLY_LAYOUT_TERMINAL },
        { "ctrl",                                      2140,  66,  PLY_LAYOUT_TERMINAL },
        { "cz",                                        2206,  47,  PLY_LAYOUT_TERMINAL },
        { "de",                                        2253,  51,  PLY_LAYOUT_TERMINAL },
        { "defkeymap",                                 2304,  170, PLY_LAYOUT_TERMINAL },
        { "dk",                                        2474,  53,  PLY_LAYOUT_TERMINAL },
        { "dz",                                        2527,  50,  PLY_LAYOUT_TERMINAL },
        { "ee",                                        2577,  50,  PLY_LAYOUT_TERMINAL },
        { "emacs",                                     2627,  106, PLY_LAYOUT_TERMINAL },
        { "emacs2",                                    2733,  122, PLY_LAYOUT_TERMINAL },
        { "en",                                        2855,  51,  PLY_LAYOUT_TERMINAL },
        { "epo",                                       2906,  69,  PLY_LAYOUT_TERMINAL },
        { "es",                                        2975,  49,  PLY_LAYOUT_TERMINAL },
        { "et",                                        3024,  46,  PLY_LAYOUT_TERMINAL },
        { "euro",                                      3070,  81,  PLY_LAYOUT_TERMINAL },
        { "euro1",                                     3151,  92,  PLY_LAYOUT_TERMINAL },
        { "euro2",                                     3243,  97,  PLY_LAYOUT_TERMINAL },
        { "fa",                                        3340,  46,  PLY_LAYOUT_TERMINAL },
        { "fi",                                        3386,  38,  PLY_LAYOUT_TERMINAL },
        { "fo",                                        3424,  48,  PLY_LAYOUT_TERMINAL },
        { "fr",                                        3472,  44,  PLY_LAYOUT_TERMINAL },
        { "gb",                                        3516,  54,  PLY_LAYOUT_TERMINAL },
        { "ge",                                        3570,  52,  PLY_LAYOUT_TERMINAL },
        { "gh",                                        3622,  53,  PLY_LAYOUT_TERMINAL },
        { "gr",                                        3675,  50,  PLY_LAYOUT_TERMINAL },
        { "hr",                                        3725,  48,  PLY_LAYOUT_TERMINAL },
        { "hu",                                        3773,  50,  PLY_LAYOUT_TERMINAL },
        { "hu101",                                     3823,  96,  PLY_LAYOUT_TERMINAL },
        { "id",                                        3919,  43,  PLY_LAYOUT_TERMINAL },
        { "ie",                                        3962,  42,  PLY_LAYOUT_TERMINAL },
        { "il",                                        4004,  37,  PLY_LAYOUT_TERMINAL },
        { "in",                                        4041,  43,  PLY_LAYOUT_TERMINAL },
        { "iq",                                        4084,  43,  PLY_LAYOUT_TERMINAL },
        { "ir",                                        4127,  40,  PLY_LAYOUT_TERMINAL },
        { "is",                                        4167,  41,  PLY_LAYOUT_TERMINAL },
        { "it",                                        4208,  38,  PLY_LAYOUT_TERMINAL },
        { "it2",                                       4246,  54,  PLY_LAYOUT_TERMINAL },
        { "jp",                                        4300,  46,  PLY_LAYOUT_TERMINAL },
        { "jp106",                                     4346,  96,  PLY_LAYOUT_TERMINAL },
        { "kazakh",                                    4442,  113, PLY_LAYOUT_TERMINAL },
        { "ke",                                        4555,  49,  PLY_LAYOUT_TERMINAL },
        { "keypad",                                    4604,  114, PLY_LAYOUT_TERMINAL },
        { "ko",                                        4718,  51,  PLY_LAYOUT_TERMINAL },
        { "koy",                                       4769,  67,  PLY_LAYOUT_TERMINAL },
        { "kr",                                        4836,  47,  PLY_LAYOUT_TERMINAL },
        { "ky",                                        4883,  50,  PLY_LAYOUT_TERMINAL },
        { "kyrgyz",                                    4933,  108, PLY_LAYOUT_TERMINAL },
        { "kz",                                        5041,  48,  PLY_LAYOUT_TERMINAL },
        { "la",                                        5089,  42,  PLY_LAYOUT_TERMINAL },
        { "latam",                                     5131,  96,  PLY_LAYOUT_TERMINAL },
        { "lk",                                        5227,  44,  PLY_LAYOUT_TERMINAL },
        { "lt",                                        5271,  38,  PLY_LAYOUT_TERMINAL },
        { "lv",                                        5309,  43,  PLY_LAYOUT_TERMINAL },
        { "ma",                                        5352,  60,  PLY_LAYOUT_TERMINAL },
        { "no",                                        5412,  52,  PLY_LAYOUT_TERMINAL },
        { "pl",                                        5464,  45,  PLY_LAYOUT_TERMINAL },
        { "pt",                                        5509,  46,  PLY_LAYOUT_TERMINAL },
        { "se",                                        5555,  48,  PLY_LAYOUT_TERMINAL },
        { "template",                                  5603,  142, PLY_LAYOUT_TERMINAL },
        { "uk",                                        5745,  53,  PLY_LAYOUT_TERMINAL },
        { "us",                                        5798,  50,  PLY_LAYOUT_TERMINAL },
        { "md",                                        5848,  61,  PLY_LAYOUT_TERMINAL },
        { "me",                                        5909,  60,  PLY_LAYOUT_TERMINAL },
        { "mk",                                        5969,  62,  PLY_LAYOUT_TERMINAL },
        { "mk0",                                       6031,  79,  PLY_LAYOUT_TERMINAL },
        { "ml",                                        6110,  55,  PLY_LAYOUT_TERMINAL },
        { "mm",                                        6165,  71,  PLY_LAYOUT_TERMINAL },
        { "mod",                                       6236,  78,  PLY_LAYOUT_TERMINAL },
        { "mt",                                        6314,  56,  PLY_LAYOUT_TERMINAL },
        { "neo",                                       6370,  68,  PLY_LAYOUT_TERMINAL },
        { "neoqwertz",                                 6438,  162, PLY_LAYOUT_TERMINAL },
        { "ng",                                        6600,  51,  PLY_LAYOUT_TERMINAL },
        { "nl",                                        6651,  45,  PLY_LAYOUT_TERMINAL },
        { "nl2",                                       6696,  60,  PLY_LAYOUT_TERMINAL },
        { "nz",                                        6756,  49,  PLY_LAYOUT_TERMINAL },
        { "pc110",                                     6805,  95,  PLY_LAYOUT_TERMINAL },
        { "ph",                                        6900,  51,  PLY_LAYOUT_TERMINAL },
        { "pl1",                                       6951,  55,  PLY_LAYOUT_TERMINAL },
        { "pl2",                                       7006,  60,  PLY_LAYOUT_TERMINAL },
        { "pl3",                                       7066,  61,  PLY_LAYOUT_TERMINAL },
        { "pl4",                                       7127,  62,  PLY_LAYOUT_TERMINAL },
        { "ro",                                        7189,  47,  PLY_LAYOUT_TERMINAL },
        { "rs",                                        7236,  44,  PLY_LAYOUT_TERMINAL },
        { "ru",                                        7280,  45,  PLY_LAYOUT_TERMINAL },
        { "ru1",                                       7325,  58,  PLY_LAYOUT_TERMINAL },
        { "ru2",                                       7383,  63,  PLY_LAYOUT_TERMINAL },
        { "ru3",                                       7446,  64,  PLY_LAYOUT_TERMINAL },
        { "ru4",                                       7510,  65,  PLY_LAYOUT_TERMINAL },
        { "ruwin",                                     7575,  95,  PLY_LAYOUT_TERMINAL },
        { "sg",                                        7670,  49,  PLY_LAYOUT_TERMINAL },
        { "si",                                        7719,  40,  PLY_LAYOUT_TERMINAL },
        { "sk",                                        7759,  50,  PLY_LAYOUT_TERMINAL },
        { "slovene",                                   7809,  122, PLY_LAYOUT_TERMINAL },
        { "sr",                                        7931,  46,  PLY_LAYOUT_TERMINAL },
        { "sunkeymap",                                 7977,  174, PLY_LAYOUT_TERMINAL },
        { "sv",                                        8151,  49,  PLY_LAYOUT_TERMINAL },
        { "sy",                                        8200,  49,  PLY_LAYOUT_TERMINAL },
        { "tj",                                        8249,  38,  PLY_LAYOUT_TERMINAL },
        { "tm",                                        8287,  57,  PLY_LAYOUT_TERMINAL },
        { "tr",                                        8344,  44,  PLY_LAYOUT_TERMINAL },
        { "tralt",                                     8388,  79,  PLY_LAYOUT_TERMINAL },
        { "trf",                                       8467,  56,  PLY_LAYOUT_TERMINAL },
        { "trq",                                       8523,  59,  PLY_LAYOUT_TERMINAL },
        { "ttwin",                                     8582,  90,  PLY_LAYOUT_TERMINAL },
        { "tw",                                        8672,  56,  PLY_LAYOUT_TERMINAL },
        { "ua",                                        8728,  51,  PLY_LAYOUT_TERMINAL },
        { "unicode",                                   8779,  124, PLY_LAYOUT_TERMINAL },
        { "us1",                                       8903,  61,  PLY_LAYOUT_TERMINAL },
        { "uz",                                        8964,  50,  PLY_LAYOUT_TERMINAL },
        { "vn",                                        9014,  51,  PLY_LAYOUT_TERMINAL },
        { "wangbe",                                    9065,  127, PLY_LAYOUT_TERMINAL },
        { "wangbe2",                                   9192,  144, PLY_LAYOUT_TERMINAL },
        { "windowkeys",                                9336,  188, PLY_LAYOUT_TERMINAL },
        { "Albanian",                                  9524,  139, PLY_LAYOUT_XKB      },
        { "Amharic",                                   9663,  134, PLY_LAYOUT_XKB      },
        { "Armenian",                                  9797,  152, PLY_LAYOUT_XKB      },
        { "Arabic",                                    9949,  107, PLY_LAYOUT_XKB      },
        { "Arabic (Egypt)",                            10056, 211, PLY_LAYOUT_XKB      },
        { "Arabic (Iraq)",                             10267, 186, PLY_LAYOUT_XKB      },
        { "Arabic (Morocco)",                          10453, 249, PLY_LAYOUT_XKB      },
        { "Arabic (Syria)",                            10702, 200, PLY_LAYOUT_XKB      },
        { "Azerbaijani",                               10902, 172, PLY_LAYOUT_XKB      },
        { "Bambara",                                   11074, 141, PLY_LAYOUT_XKB      },
        { "Bangla",                                    11215, 113, PLY_LAYOUT_XKB      },
        { "Belarusian",                                11328, 162, PLY_LAYOUT_XKB      },
        { "Belgian",                                   11490, 121, PLY_LAYOUT_XKB      },
        { "Berber (Algeria, Latin)",                   11611, 317, PLY_LAYOUT_XKB      },
        { "Bosnian",                                   11928, 126, PLY_LAYOUT_XKB      },
        { "Braille",                                   12054, 107, PLY_LAYOUT_XKB      },
        { "Bulgarian",                                 12161, 150, PLY_LAYOUT_XKB      },
        { "Burmese",                                   12311, 139, PLY_LAYOUT_XKB      },
        { "Chinese",                                   12450, 125, PLY_LAYOUT_XKB      },
        { "Croatian",                                  12575, 134, PLY_LAYOUT_XKB      },
        { "Czech",                                     12709, 99,  PLY_LAYOUT_XKB      },
        { "Danish",                                    12808, 111, PLY_LAYOUT_XKB      },
        { "Dari",                                      12919, 75,  PLY_LAYOUT_XKB      },
        { "Dhivehi",                                   12994, 120, PLY_LAYOUT_XKB      },
        { "Dutch",                                     13114, 98,  PLY_LAYOUT_XKB      },
        { "Dzongkha",                                  13212, 155, PLY_LAYOUT_XKB      },
        { "English (Australia)",                       13367, 267, PLY_LAYOUT_XKB      },
        { "English (Cameroon)",                        13634, 285, PLY_LAYOUT_XKB      },
        { "English (Ghana)",                           13919, 232, PLY_LAYOUT_XKB      },
        { "English (New Zealand)",                     14151, 324, PLY_LAYOUT_XKB      },
        { "English (Nigeria)",                         14475, 245, PLY_LAYOUT_XKB      },
        { "English (South Africa)",                    14720, 310, PLY_LAYOUT_XKB      },
        { "English (UK)",                              15030, 185, PLY_LAYOUT_XKB      },
        { "English (US)",                              15215, 182, PLY_LAYOUT_XKB      },
        { "Esperanto",                                 15397, 156, PLY_LAYOUT_XKB      },
        { "Estonian",                                  15553, 135, PLY_LAYOUT_XKB      },
        { "Faroese",                                   15688, 125, PLY_LAYOUT_XKB      },
        { "Filipino",                                  15813, 119, PLY_LAYOUT_XKB      },
        { "Finnish",                                   15932, 115, PLY_LAYOUT_XKB      },
        { "French",                                    16047, 110, PLY_LAYOUT_XKB      },
        { "French (Canada)",                           16157, 237, PLY_LAYOUT_XKB      },
        { "French (Democratic Republic of the Congo)", 16394, 594, PLY_LAYOUT_XKB      },
        { "French (Togo)",                             16988, 206, PLY_LAYOUT_XKB      },
        { "Georgian",                                  17194, 144, PLY_LAYOUT_XKB      },
        { "German",                                    17338, 128, PLY_LAYOUT_XKB      },
        { "German (Austria)",                          17466, 252, PLY_LAYOUT_XKB      },
        { "German (Switzerland)",                      17718, 316, PLY_LAYOUT_XKB      },
        { "Greek",                                     18034, 102, PLY_LAYOUT_XKB      },
        { "Hebrew",                                    18136, 126, PLY_LAYOUT_XKB      },
        { "Hungarian",                                 18262, 160, PLY_LAYOUT_XKB      },
        { "Icelandic",                                 18422, 138, PLY_LAYOUT_XKB      },
        { "Indian",                                    18560, 101, PLY_LAYOUT_XKB      },
        { "Indonesian (Latin)",                        18661, 259, PLY_LAYOUT_XKB      },
        { "Irish",                                     18920, 77,  PLY_LAYOUT_XKB      },
        { "Italian",                                   18997, 103, PLY_LAYOUT_XKB      },
        { "Japanese",                                  19100, 144, PLY_LAYOUT_XKB      },
        { "Kazakh",                                    19244, 117, PLY_LAYOUT_XKB      },
        { "Khmer (Cambodia)",                          19361, 272, PLY_LAYOUT_XKB      },
        { "Korean",                                    19633, 115, PLY_LAYOUT_XKB      },
        { "Kyrgyz",                                    19748, 112, PLY_LAYOUT_XKB      },
        { "Lao",                                       19860, 67,  PLY_LAYOUT_XKB      },
        { "Latvian",                                   19927, 116, PLY_LAYOUT_XKB      },
        { "Lithuanian",                                20043, 160, PLY_LAYOUT_XKB      },
        { "Macedonian",                                20203, 181, PLY_LAYOUT_XKB      },
        { "Malay (Jawi, Arabic Keyboard)",             20384, 423, PLY_LAYOUT_XKB      },
        { "Maltese",                                   20807, 125, PLY_LAYOUT_XKB      },
        { "Moldavian",                                 20932, 158, PLY_LAYOUT_XKB      },
        { "Mongolian",                                 21090, 162, PLY_LAYOUT_XKB      },
        { "Montenegrin",                               21252, 192, PLY_LAYOUT_XKB      },
        { "Nepali",                                    21444, 106, PLY_LAYOUT_XKB      },
        { "N'Ko (AZERTY)",                             21550, 225, PLY_LAYOUT_XKB      },
        { "Norwegian",                                 21775, 168, PLY_LAYOUT_XKB      },
        { "Persian",                                   21943, 118, PLY_LAYOUT_XKB      },
        { "Polish",                                    22061, 100, PLY_LAYOUT_XKB      },
        { "Portuguese",                                22161, 173, PLY_LAYOUT_XKB      },
        { "Portuguese (Brazil)",                       22334, 279, PLY_LAYOUT_XKB      },
        { "Romanian",                                  22613, 154, PLY_LAYOUT_XKB      },
        { "Russian",                                   22767, 122, PLY_LAYOUT_XKB      },
        { "Serbian",                                   22889, 122, PLY_LAYOUT_XKB      },
        { "Sinhala (phonetic)",                        23011, 262, PLY_LAYOUT_XKB      },
        { "Slovak",                                    23273, 111, PLY_LAYOUT_XKB      },
        { "Slovenian",                                 23384, 151, PLY_LAYOUT_XKB      },
        { "Spanish",                                   23535, 125, PLY_LAYOUT_XKB      },
        { "Spanish (Latin American)",                  23660, 355, PLY_LAYOUT_XKB      },
        { "Swahili (Kenya)",                           24015, 228, PLY_LAYOUT_XKB      },
        { "Swahili (Tanzania)",                        24243, 267, PLY_LAYOUT_XKB      },
        { "Swedish",                                   24510, 132, PLY_LAYOUT_XKB      },
        { "Taiwanese",                                 24642, 164, PLY_LAYOUT_XKB      },
        { "Tajik",                                     24806, 87,  PLY_LAYOUT_XKB      },
        { "Thai",                                      24893, 78,  PLY_LAYOUT_XKB      },
        { "Tswana",                                    24971, 124, PLY_LAYOUT_XKB      },
        { "Turkmen",                                   25095, 142, PLY_LAYOUT_XKB      },
        { "Turkish",                                   25237, 121, PLY_LAYOUT_XKB      },
        { "Ukrainian",                                 25358, 149, PLY_LAYOUT_XKB      },
        { "Urdu (Pakistan)",                           25507, 227, PLY_LAYOUT_XKB      },
        { "Uzbek",                                     25734, 105, PLY_LAYOUT_XKB      },
        { "Vietnamese",                                25839, 179, PLY_LAYOUT_XKB      },
        { "Wolof",                                     26018, 106, PLY_LAYOUT_XKB      },
        { "A user-defined custom Layout",              26124, 423, PLY_LAYOUT_XKB      },
        { NULL,                                        } /* End of array marker */
};
